# Meshemy: Python toolbelt for manipulating mesh
Consolidation package for manipulating mesh. Comes with cookbook models from each package

## Installation
```shell
pip install meshemy
```
Use it in your poetry package
```shell
poetry add meshemy
```
